@@ -67,6 +67,6 @@ read_rewrite_def_impl <- function() {
 
 #' @noRd
 apply_rep_all <- function(text, pattern, rep) {
-  res <- stringi::stri_replace_all_fixed(text, pattern = pattern, replace = rep, vectorise_all = FALSE)
+  res <- stringi::stri_replace_all_fixed(text, pattern = pattern, replacement = rep, vectorise_all = FALSE)
   stringi::stri_trans_nfkc(res)
 }
